user/dev discussion of public-inbox itself
 help / color / mirror / code / Atom feed
From: Eric Wong <e@80x24.org>
To: meta@public-inbox.org
Subject: [PATCH 4/4] httpd/async + qspawn: rename {fh} fields
Date: Fri, 23 Dec 2022 11:05:15 +0000	[thread overview]
Message-ID: <20221223110515.19907-5-e@80x24.org> (raw)
In-Reply-To: <20221223110515.19907-1-e@80x24.org>

Use more unique names within the project to minimize confusion
since these packages interact quite a bit and using identical
names leads to needless confusion.
---
 lib/PublicInbox/HTTPD/Async.pm | 16 +++++++++-------
 lib/PublicInbox/Qspawn.pm      |  4 ++--
 2 files changed, 11 insertions(+), 9 deletions(-)

diff --git a/lib/PublicInbox/Qspawn.pm b/lib/PublicInbox/Qspawn.pm
index da7cd74f..6e245389 100644
--- a/lib/PublicInbox/Qspawn.pm
+++ b/lib/PublicInbox/Qspawn.pm
@@ -187,7 +187,7 @@ sub event_step {
 	my ($self, $err) = @_; # $err: $!
 	warn "psgi_{return,qx} $err" if defined($err);
 	finish($self);
-	my ($fh, $qx_fh) = delete(@$self{qw(fh qx_fh)});
+	my ($fh, $qx_fh) = delete(@$self{qw(qfh qx_fh)});
 	$fh->close if $fh; # async-only (psgi_return)
 }
 
@@ -242,7 +242,7 @@ sub psgi_return_init_cb {
 		# done reading headers, handoff to read body
 		my $fh = $wcb->($r); # scalar @$r == 2
 		$fh = $filter->attach($fh) if $filter;
-		$self->{fh} = $fh;
+		$self->{qfh} = $fh;
 		$async->async_pass($env->{'psgix.io'}, $fh,
 					delete($self->{hdr_buf}));
 	} else { # for synchronous PSGI servers

      parent reply	other threads:[~2022-12-23 11:05 UTC|newest]

Thread overview: 5+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2022-12-23 11:05 [PATCH 0/4] httpd/async fixes for coderepos Eric Wong
2022-12-23 11:05 ` [PATCH 1/4] httpd: avoid crash on cgit -> coderepo 404 fallback Eric Wong
2022-12-23 11:05 ` [PATCH 2/4] httpd/async: remove useless undef Eric Wong
2022-12-23 11:05 ` [PATCH 3/4] qspawn: shorten life of {hdr_buf} in generic code path Eric Wong
2022-12-23 11:05 ` Eric Wong [this message]

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

  List information: https://public-inbox.org/README

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20221223110515.19907-5-e@80x24.org \
    --to=e@80x24.org \
    --cc=meta@public-inbox.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
Code repositories for project(s) associated with this public inbox

	https://80x24.org/public-inbox.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).
diff --git a/lib/PublicInbox/HTTPD/Async.pm b/lib/PublicInbox/HTTPD/Async.pm
index 75b3bd50..e03daafa 100644
--- a/lib/PublicInbox/HTTPD/Async.pm
+++ b/lib/PublicInbox/HTTPD/Async.pm
@@ -37,7 +37,7 @@ sub new {
 		arg => $arg, # arg for $cb
 		end_obj => $end_obj, # like END{}, can ->event_step
 	}, $class;
-	my $pp = tied *$io;
+	my $pp = tied *$io; # ProcessPipe
 	$pp->{fh}->blocking(0) // die "$io->blocking(0): $!";
 	$self->SUPER::new($io, EPOLLIN);
 }
@@ -54,7 +54,7 @@ sub event_step {
 		# and 65536 is the default Linux pipe size
 		my $r = sysread($sock, my $buf, 65536);
 		if ($r) {
-			$self->{fh}->write($buf); # may call $http->close
+			$self->{ofh}->write($buf); # may call $http->close
 			# let other clients get some work done, too
 			return if $http->{sock}; # !closed
 
@@ -63,7 +63,7 @@ sub event_step {
 			return; # EPOLLIN means we'll be notified
 		}
 
 		# Done! Error handling will happen in $self->{fh}->close
 		# called by end_obj->event_step handler
 		delete $http->{forward};
 		$self->close; # queues end_obj->event_step to be called
@@ -71,9 +71,11 @@ sub event_step {
 }
 
 # once this is called, all data we read is passed to the
-# to the PublicInbox::HTTP instance ($http) via $fh->write
+# to the PublicInbox::HTTP instance ($http) via $ofh->write
+# $ofh is typically PublicInbox::HTTP::{Chunked,Identity}, but
+# may be PublicInbox::GzipFilter or $PublicInbox::Qspawn::qx_fh
 sub async_pass {
-	my ($self, $http, $fh, $bref) = @_;
+	my ($self, $http, $ofh, $bref) = @_;
 	# In case the client HTTP connection ($http) dies, it
 	# will automatically close this ($self) object.
 	$http->{forward} = $self;
@@ -82,10 +84,10 @@ sub async_pass {
 	# This is typically PublicInbox:HTTP::{chunked,identity}_wcb,
 	# but may be PublicInbox::GzipFilter::write.  PSGI requires
 	# *_wcb methods respond to ->write (and ->close), not ->print
-	$fh->write($$bref);
+	$ofh->write($$bref);
 
 	$self->{http} = $http;
-	$self->{fh} = $fh;
+	$self->{ofh} = $ofh;
 }
 
 # may be called as $forward->close in PublicInbox::HTTP or EOF (event_step)
@@ -63,7 +63,7 @@ sub event_step {
 		}
 
-		# Done! Error handling will happen in $self->{fh}->close
+		# Done! Error handling will happen in $self->{ofh}->close
 		# called by end_obj->event_step handler
 		delete $http->{forward};